@@ -1,7 +1,5 @@
 /*
- * Copyright (c) 2014 LastPass. All Rights Reserved.
- *
- *
+ * Copyright (c) 2014-2015 LastPass.
  */
 
 #include "blob.h"
@@ -23,7 +21,14 @@
 #define htobe32(x) OSSwapHostToBigInt32(x)
 #define be32toh(x) OSSwapBigToHostInt32(x)
 #else
-#include <endian.h>
+# if (defined(__unix__) || defined(unix)) && !defined(USG)
+#  include <sys/param.h>
+# endif
+# if defined(BSD)
+#  include <sys/endian.h>
+# else
+#  include <endian.h>
+# endif
 #endif
 
 void share_free(struct share *share)
@@ -163,6 +168,7 @@ static bool read_item(struct chunk *chunk, struct item *item)
 static char *read_hex_string(struct chunk *chunk)
 {
 	struct item item;
+	int result;
 	char *str = NULL;
 
 	if (!read_item(chunk, &item))
@@ -170,8 +176,8 @@ static char *read_hex_string(struct chunk *chunk)
 	if (item.len == 0)
 		return xstrdup("");
 
-	hex_to_bytes(item.data, &str);
-	if (!*str) {
+	result = hex_to_bytes(item.data, &str);
+	if (result) {
 		free(str);
 		return NULL;
 	}
@@ -732,7 +738,6 @@ void account_set_fullname(struct account *account, char *fullname, unsigned cons
 	account->fullname = fullname;
 }
 
-#ifdef PROCESS_NOTES
 struct account *notes_expand(struct account *acc)
 {
 	struct account *expand;
@@ -753,6 +758,9 @@ struct account *notes_expand(struct account *acc)
 	expand->fullname = xstrdup(acc->fullname);
 	share_assign(acc->share, &expand->share);
 
+	if (strncmp(acc->note, "NoteType:", 9))
+		return NULL;
+
 	for (start = acc->note; ; ) {
 		lf = strchrnul(start, '\n');
 		if (lf - start < 0)
@@ -844,13 +852,3 @@ struct account *notes_collapse(struct account *acc)
 
 	return collapse;
 }
-#else
-struct account *notes_expand(__attribute__((unused)) struct account *acc)
-{
-	return NULL;
-}
-struct account *notes_collapse(__attribute__((unused)) struct account *acc)
-{
-	die("Note processing is disabled in this build");
-}
-#endif
